@@ -3,9 +3,9 @@ import time
 from urllib.parse import urlparse
 import requests
 
-from requests.sessions import RequestsCookieJar
+from .const import XML_HEADERS
 
-XML_HEADERS = {"X-Requested-With": "XMLHttpRequest"}
+from requests.sessions import RequestsCookieJar
 
 
 def parse_single(text, regex):
@@ -40,21 +40,37 @@ class Page:
 
         self.url = url
         parsed_url = urlparse(url)
-        # Get file slug from URL
-        self.slug = parse_single(parsed_url.path, r'/file/([^\\]*)/')
-        if self.slug is None:
-            raise RuntimeError("Cannot parse file slug from Uloz.to URL")
 
-        r = requests.get(url)
+        cookies = None
+        # special case for Pornfile.cz run by Uloz.to - confirmation is needed
+        if parsed_url.hostname == "pornfile.cz":
+            r = requests.post("https://pornfile.cz/porn-disclaimer/", data={
+                "agree": "Souhlasím",
+                "_do": "pornDisclaimer-submit",
+            })
+            cookies = r.cookies
+
+        # If file is file-tracking link we need to get normal file link from it
+        if url.startswith('{uri.scheme}://{uri.netloc}/file-tracking/'.format(uri=parsed_url)):
+            r = requests.get(url, allow_redirects=False, cookies=cookies)
+            if 'Location' in r.headers:
+                self.url = r.headers['Location']
+                parsed_url = urlparse(self.url)
+
+        r = requests.get(self.url, cookies=cookies)
         self.baseURL = "{uri.scheme}://{uri.netloc}".format(uri=parsed_url)
 
         if r.status_code == 451:
             raise RuntimeError("File was deleted from Uloz.to due to legal reasons (status code 451)")
         elif r.status_code != 200:
-            raise RuntimeError("Uloz.to returned status code", r.status_code)
+            raise RuntimeError(f"Uloz.to returned status code {r.status_code}, file does not exist")
+
+        # Get file slug from URL
+        self.slug = parse_single(parsed_url.path, r'/file/([^\\]*)/')
+        if self.slug is None:
+            raise RuntimeError("Cannot parse file slug from Uloz.to URL")
 
         self.body = r.text
-        self.cookies = r.cookies
 
     def parse(self):
         """Try to parse all information from the Uloz.to page (filename, download links, ...)
@@ -140,7 +156,16 @@ class Page:
                 RequestsCookieJar: Obtained cookies from the page
         """
 
-        r = requests.get(self.captchaURL)
+        cookies = None
+        # special case for Pornfile.cz run by Uloz.to - confirmation is needed
+        if urlparse(self.url).hostname == "pornfile.cz":
+            r = requests.post("https://pornfile.cz/porn-disclaimer/", data={
+                "agree": "Souhlasím",
+                "_do": "pornDisclaimer-submit",
+            })
+            cookies = r.cookies
+
+        r = requests.get(self.captchaURL, cookies=cookies)
 
         # <img class="xapca-image" src="//xapca1.uloz.to/0fdc77841172eb6926bf57fe2e8a723226951197/image.jpg" alt="">
         captcha_image = parse_single(r.text, r'<img class="xapca-image" src="([^"]*)" alt="">')
